@@ -9,6 +9,7 @@ from .models.seresnet import *
 from .models.sepreresnet import *
 from .models.seresnext import *
 from .models.senet import *
+from .models.resnesta import *
 from .models.ibnresnet import *
 from .models.ibnbresnet import *
 from .models.ibnresnext import *
@@ -19,6 +20,7 @@ from .models.bamresnet import *
 from .models.cbamresnet import *
 from .models.resattnet import *
 from .models.sknet import *
+from .models.scnet import *
 from .models.diaresnet import *
 from .models.diapreresnet import *
 from .models.pyramidnet import *
@@ -54,6 +56,8 @@ from .models.shufflenetv2 import *
 from .models.shufflenetv2b import *
 from .models.menet import *
 from .models.mobilenet import *
+from .models.mobilenetb import *
+from .models.fdmobilenet import *
 from .models.mobilenetv2 import *
 from .models.mobilenetv3 import *
 from .models.igcv3 import *
@@ -112,6 +116,8 @@ from .models.pspnet import *
 from .models.deeplabv3 import *
 from .models.icnet import *
 from .models.sinet import *
+from .models.bisenet import *
+from .models.danet import *
 
 from .models.alphapose_coco import *
 from .models.simplepose_coco import *
@@ -125,6 +131,7 @@ from .models.centernet import *
 from .models.lffd import *
 
 from .models.voca import *
+from .models.nvpattexp import *
 
 from .models.superpointnet import *
 
@@ -134,7 +141,9 @@ from .models.superpointnet import *
 # from .models.others.oth_prnet import *
 # from .models.others.oth_sinet import *
 # from .models.others.oth_ibppose import *
-
+# from .models.others.oth_bisenet1 import *
+from .models.others.oth_regnet import *
+from .models.regnet import *
 
 __all__ = ['get_model']
 
@@ -264,6 +273,15 @@ _models = {
     'senet103': senet103,
     'senet154': senet154,
 
+    'resnestabc14': resnestabc14,
+    'resnesta18': resnesta18,
+    'resnestabc26': resnestabc26,
+    'resnesta50': resnesta50,
+    'resnesta101': resnesta101,
+    'resnesta152': resnesta152,
+    'resnesta200': resnesta200,
+    'resnesta269': resnesta269,
+
     'ibn_resnet50': ibn_resnet50,
     'ibn_resnet101': ibn_resnet101,
     'ibn_resnet152': ibn_resnet152,
@@ -313,6 +331,11 @@ _models = {
     'sknet101': sknet101,
     'sknet152': sknet152,
 
+    'scnet50': scnet50,
+    'scnet101': scnet101,
+    'scneta50': scneta50,
+    'scneta101': scneta101,
+
     'diaresnet10': diaresnet10,
     'diaresnet12': diaresnet12,
     'diaresnet14': diaresnet14,
@@ -516,6 +539,11 @@ _models = {
     'mobilenet_wd2': mobilenet_wd2,
     'mobilenet_wd4': mobilenet_wd4,
 
+    'mobilenetb_w1': mobilenetb_w1,
+    'mobilenetb_w3d4': mobilenetb_w3d4,
+    'mobilenetb_wd2': mobilenetb_wd2,
+    'mobilenetb_wd4': mobilenetb_wd4,
+
     'fdmobilenet_w1': fdmobilenet_w1,
     'fdmobilenet_w3d4': fdmobilenet_w3d4,
     'fdmobilenet_wd2': fdmobilenet_wd2,
@@ -888,6 +916,9 @@ _models = {
     'isqrtcovresnet101': isqrtcovresnet101,
     'isqrtcovresnet101b': isqrtcovresnet101b,
 
+    'resneta10': resneta10,
+    'resnetabc14b': resnetabc14b,
+    'resneta18': resneta18,
     'resneta50b': resneta50b,
     'resneta101b': resneta101b,
     'resneta152b': resneta152b,
@@ -989,6 +1020,11 @@ _models = {
 
     'sinet_cityscapes': sinet_cityscapes,
 
+    'bisenet_resnet18_celebamaskhq': bisenet_resnet18_celebamaskhq,
+
+    'danet_resnetd50b_cityscapes': danet_resnetd50b_cityscapes,
+    'danet_resnetd101b_cityscapes': danet_resnetd101b_cityscapes,
+
     'alphapose_fastseresnet101b_coco': alphapose_fastseresnet101b_coco,
 
     'simplepose_resnet18_coco': simplepose_resnet18_coco,
@@ -1024,6 +1060,7 @@ _models = {
     'lffd25x8s560v1_widerface': lffd25x8s560v1_widerface,
 
     'voca8flame': voca8flame,
+    'nvpattexp116bazel76': nvpattexp116bazel76,
 
     'superpointnet': superpointnet,
 
@@ -1042,6 +1079,60 @@ _models = {
     # 'oth_sinet_cityscapes': oth_sinet_cityscapes,
 
     # 'oth_ibppose': oth_ibppose,
+
+    # 'oth_bisenet': oth_bisenet,
+
+    'regnetx_002': regnetx_002,
+    'regnetx_004': regnetx_004,
+    'regnetx_006': regnetx_006,
+    'regnetx_008': regnetx_008,
+    'regnetx_016': regnetx_016,
+    'regnetx_032': regnetx_032,
+    'regnetx_040': regnetx_040,
+    'regnetx_064': regnetx_064,
+    'regnetx_080': regnetx_080,
+    'regnetx_120': regnetx_120,
+    'regnetx_160': regnetx_160,
+    'regnetx_320': regnetx_320,
+
+    'regnety_002': regnety_002,
+    'regnety_004': regnety_004,
+    'regnety_006': regnety_006,
+    'regnety_008': regnety_008,
+    'regnety_016': regnety_016,
+    'regnety_032': regnety_032,
+    'regnety_040': regnety_040,
+    'regnety_064': regnety_064,
+    'regnety_080': regnety_080,
+    'regnety_120': regnety_120,
+    'regnety_160': regnety_160,
+    'regnety_320': regnety_320,
+
+    'regnetx002': regnetx002,
+    'regnetx004': regnetx004,
+    'regnetx006': regnetx006,
+    'regnetx008': regnetx008,
+    'regnetx016': regnetx016,
+    'regnetx032': regnetx032,
+    'regnetx040': regnetx040,
+    'regnetx064': regnetx064,
+    'regnetx080': regnetx080,
+    'regnetx120': regnetx120,
+    'regnetx160': regnetx160,
+    'regnetx320': regnetx320,
+
+    'regnety002': regnety002,
+    'regnety004': regnety004,
+    'regnety006': regnety006,
+    'regnety008': regnety008,
+    'regnety016': regnety016,
+    'regnety032': regnety032,
+    'regnety040': regnety040,
+    'regnety064': regnety064,
+    'regnety080': regnety080,
+    'regnety120': regnety120,
+    'regnety160': regnety160,
+    'regnety320': regnety320,
 }
 
 
