@@ -1,5 +1,5 @@
 """
-    ChannelNet, implemented in PyTorch.
+    ChannelNet for ImageNet-1K, implemented in PyTorch.
     Original paper: 'ChannelNets: Compact and Efficient Convolutional Neural Networks via Channel-Wise Convolutions,'
     https://arxiv.org/abs/1809.01330.
 """
@@ -482,7 +482,7 @@ class ChannelNet(nn.Module):
                 else:
                     in_channels = out_channels[-1]
             self.features.add_module("stage{}".format(i + 1), stage)
-        self.features.add_module('final_pool', nn.AvgPool2d(
+        self.features.add_module("final_pool", nn.AvgPool2d(
             kernel_size=7,
             stride=1))
 
@@ -508,7 +508,7 @@ class ChannelNet(nn.Module):
 
 def get_channelnet(model_name=None,
                    pretrained=False,
-                   root=os.path.join('~', '.torch', 'models'),
+                   root=os.path.join("~", ".torch", "models"),
                    **kwargs):
     """
     Create ChannelNet model with specific parameters.
@@ -575,7 +575,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -593,7 +592,7 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != channelnet or weight_count == 3875112)
 
-        x = Variable(torch.randn(1, 3, 224, 224))
+        x = torch.randn(1, 3, 224, 224)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
