@@ -2,11 +2,12 @@
     Common routines for models in PyTorch.
 """
 
-__all__ = ['round_channels', 'Identity', 'Swish', 'HSigmoid', 'HSwish', 'get_activation_layer', 'conv1x1', 'conv3x3',
-           'depthwise_conv3x3', 'ConvBlock', 'conv1x1_block', 'conv3x3_block', 'conv7x7_block', 'dwconv_block',
-           'dwconv3x3_block', 'dwconv5x5_block', 'dwsconv3x3_block', 'PreConvBlock', 'pre_conv1x1_block',
-           'pre_conv3x3_block', 'DeconvBlock', 'NormActivation', 'InterpolationBlock', 'ChannelShuffle',
-           'ChannelShuffle2', 'SEBlock', 'DucBlock', 'IBN', 'DualPathSequential', 'Concurrent', 'SequentialConcurrent',
+__all__ = ['round_channels', 'Identity', 'Swish', 'HSigmoid', 'HSwish', 'get_activation_layer', 'SelectableDense',
+           'DenseBlock', 'ConvBlock1d', 'conv1x1', 'conv3x3', 'depthwise_conv3x3', 'ConvBlock', 'conv1x1_block',
+           'conv3x3_block', 'conv7x7_block', 'dwconv_block', 'dwconv3x3_block', 'dwconv5x5_block', 'dwsconv3x3_block',
+           'PreConvBlock', 'pre_conv1x1_block', 'pre_conv3x3_block', 'DeconvBlock', 'NormActivation',
+           'InterpolationBlock', 'ChannelShuffle', 'ChannelShuffle2', 'SEBlock', 'SABlock', 'SAConvBlock',
+           'saconv3x3_block', 'DucBlock', 'IBN', 'DualPathSequential', 'Concurrent', 'SequentialConcurrent',
            'ParametricSequential', 'ParametricConcurrent', 'Hourglass', 'SesquialteralHourglass',
            'MultiOutputSequential', 'ParallelConcurent', 'Flatten', 'HeatmapMaxDetBlock']
 
@@ -15,6 +16,7 @@ from inspect import isfunction
 import torch
 import torch.nn as nn
 import torch.nn.functional as F
+from torch.nn.parameter import Parameter
 
 
 def round_channels(channels,
@@ -124,6 +126,172 @@ def get_activation_layer(activation):
         return activation
 
 
+class SelectableDense(nn.Module):
+    """
+    Selectable dense layer.
+
+    Parameters:
+    ----------
+    in_features : int
+        Number of input features.
+    out_features : int
+        Number of output features.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    num_options : int, default 1
+        Number of selectable options.
+    """
+    def __init__(self,
+                 in_features,
+                 out_features,
+                 bias=False,
+                 num_options=1):
+        super(SelectableDense, self).__init__()
+        self.in_features = in_features
+        self.out_features = out_features
+        self.use_bias = bias
+        self.num_options = num_options
+        self.weight = Parameter(torch.Tensor(num_options, out_features, in_features))
+        if bias:
+            self.bias = Parameter(torch.Tensor(num_options, out_features))
+        else:
+            self.register_parameter("bias", None)
+
+    def forward(self, x, indices):
+        weight = torch.index_select(self.weight, dim=0, index=indices)
+        x = x.unsqueeze(-1)
+        x = weight.bmm(x)
+        x = x.squeeze(dim=-1)
+        if self.use_bias:
+            bias = torch.index_select(self.bias, dim=0, index=indices)
+            x += bias
+        return x
+
+    def extra_repr(self):
+        return "in_features={}, out_features={}, bias={}, num_options={}".format(
+            self.in_features, self.out_features, self.use_bias, self.num_options)
+
+
+class DenseBlock(nn.Module):
+    """
+    Standard dense block with Batch normalization and activation.
+
+    Parameters:
+    ----------
+    in_features : int
+        Number of input features.
+    out_features : int
+        Number of output features.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function or name of activation function.
+    """
+    def __init__(self,
+                 in_features,
+                 out_features,
+                 bias=False,
+                 use_bn=True,
+                 bn_eps=1e-5,
+                 activation=(lambda: nn.ReLU(inplace=True))):
+        super(DenseBlock, self).__init__()
+        self.activate = (activation is not None)
+        self.use_bn = use_bn
+
+        self.fc = nn.Linear(
+            in_features=in_features,
+            out_features=out_features,
+            bias=bias)
+        if self.use_bn:
+            self.bn = nn.BatchNorm1d(
+                num_features=out_features,
+                eps=bn_eps)
+        if self.activate:
+            self.activ = get_activation_layer(activation)
+
+    def forward(self, x):
+        x = self.fc(x)
+        if self.use_bn:
+            x = self.bn(x)
+        if self.activate:
+            x = self.activ(x)
+        return x
+
+
+class ConvBlock1d(nn.Module):
+    """
+    Standard 1D convolution block with Batch normalization and activation.
+
+    Parameters:
+    ----------
+    in_channels : int
+        Number of input channels.
+    out_channels : int
+        Number of output channels.
+    kernel_size : int
+        Convolution window size.
+    stride : int
+        Strides of the convolution.
+    padding : int
+        Padding value for convolution layer.
+    dilation : int
+        Dilation value for convolution layer.
+    groups : int, default 1
+        Number of groups.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function or name of activation function.
+    """
+    def __init__(self,
+                 in_channels,
+                 out_channels,
+                 kernel_size,
+                 stride,
+                 padding,
+                 dilation=1,
+                 groups=1,
+                 bias=False,
+                 use_bn=True,
+                 bn_eps=1e-5,
+                 activation=(lambda: nn.ReLU(inplace=True))):
+        super(ConvBlock1d, self).__init__()
+        self.activate = (activation is not None)
+        self.use_bn = use_bn
+
+        self.conv = nn.Conv1d(
+            in_channels=in_channels,
+            out_channels=out_channels,
+            kernel_size=kernel_size,
+            stride=stride,
+            padding=padding,
+            dilation=dilation,
+            groups=groups,
+            bias=bias)
+        if self.use_bn:
+            self.bn = nn.BatchNorm1d(
+                num_features=out_channels,
+                eps=bn_eps)
+        if self.activate:
+            self.activ = get_activation_layer(activation)
+
+    def forward(self, x):
+        x = self.conv(x)
+        if self.use_bn:
+            x = self.bn(x)
+        if self.activate:
+            x = self.activ(x)
+        return x
+
+
 def conv1x1(in_channels,
             out_channels,
             stride=1,
@@ -622,8 +790,10 @@ class DwsConvBlock(nn.Module):
         Dilation value for convolution layer.
     bias : bool, default False
         Whether the layer uses a bias vector.
-    use_bn : bool, default True
-        Whether to use BatchNorm layer.
+    dw_use_bn : bool, default True
+        Whether to use BatchNorm layer (depthwise convolution block).
+    pw_use_bn : bool, default True
+        Whether to use BatchNorm layer (pointwise convolution block).
     bn_eps : float, default 1e-5
         Small float added to variance in Batch norm.
     dw_activation : function or str or None, default nn.ReLU(inplace=True)
@@ -639,7 +809,8 @@ class DwsConvBlock(nn.Module):
                  padding,
                  dilation=1,
                  bias=False,
-                 use_bn=True,
+                 dw_use_bn=True,
+                 pw_use_bn=True,
                  bn_eps=1e-5,
                  dw_activation=(lambda: nn.ReLU(inplace=True)),
                  pw_activation=(lambda: nn.ReLU(inplace=True))):
@@ -652,14 +823,14 @@ class DwsConvBlock(nn.Module):
             padding=padding,
             dilation=dilation,
             bias=bias,
-            use_bn=use_bn,
+            use_bn=dw_use_bn,
             bn_eps=bn_eps,
             activation=dw_activation)
         self.pw_conv = conv1x1_block(
             in_channels=in_channels,
             out_channels=out_channels,
             bias=bias,
-            use_bn=use_bn,
+            use_bn=pw_use_bn,
             bn_eps=bn_eps,
             activation=pw_activation)
 
@@ -675,10 +846,10 @@ def dwsconv3x3_block(in_channels,
                      padding=1,
                      dilation=1,
                      bias=False,
-                     use_bn=True,
                      bn_eps=1e-5,
                      dw_activation=(lambda: nn.ReLU(inplace=True)),
-                     pw_activation=(lambda: nn.ReLU(inplace=True))):
+                     pw_activation=(lambda: nn.ReLU(inplace=True)),
+                     **kwargs):
     """
     3x3 depthwise separable version of the standard convolution block.
 
@@ -696,8 +867,6 @@ def dwsconv3x3_block(in_channels,
         Dilation value for convolution layer.
     bias : bool, default False
         Whether the layer uses a bias vector.
-    use_bn : bool, default True
-        Whether to use BatchNorm layer.
     bn_eps : float, default 1e-5
         Small float added to variance in Batch norm.
     dw_activation : function or str or None, default nn.ReLU(inplace=True)
@@ -713,10 +882,10 @@ def dwsconv3x3_block(in_channels,
         padding=padding,
         dilation=dilation,
         bias=bias,
-        use_bn=use_bn,
         bn_eps=bn_eps,
         dw_activation=dw_activation,
-        pw_activation=pw_activation)
+        pw_activation=pw_activation,
+        **kwargs)
 
 
 class PreConvBlock(nn.Module):
@@ -990,34 +1159,60 @@ class InterpolationBlock(nn.Module):
     ----------
     scale_factor : float
         Multiplier for spatial size.
+    out_size : tuple of 2 int, default None
+        Spatial size of the output tensor for the bilinear interpolation operation.
     mode : str, default 'bilinear'
         Algorithm used for upsampling.
     align_corners : bool, default True
         Whether to align the corner pixels of the input and output tensors.
+    up : bool, default True
+        Whether to upsample or downsample.
     """
     def __init__(self,
                  scale_factor,
+                 out_size=None,
                  mode="bilinear",
-                 align_corners=True):
+                 align_corners=True,
+                 up=True):
         super(InterpolationBlock, self).__init__()
         self.scale_factor = scale_factor
+        self.out_size = out_size
         self.mode = mode
         self.align_corners = align_corners
+        self.up = up
 
-    def forward(self, x):
-        return F.interpolate(
-            input=x,
-            scale_factor=self.scale_factor,
-            mode=self.mode,
-            align_corners=self.align_corners)
+    def forward(self, x, size=None):
+        if (self.mode == "bilinear") or (size is not None):
+            out_size = self.calc_out_size(x) if size is None else size
+            return F.interpolate(
+                input=x,
+                size=out_size,
+                mode=self.mode,
+                align_corners=self.align_corners)
+        else:
+            return F.interpolate(
+                input=x,
+                scale_factor=self.scale_factor,
+                mode=self.mode,
+                align_corners=self.align_corners)
+
+    def calc_out_size(self, x):
+        if self.out_size is not None:
+            return self.out_size
+        if self.up:
+            return tuple(s * self.scale_factor for s in x.shape[2:])
+        else:
+            return tuple(s // self.scale_factor for s in x.shape[2:])
 
     def __repr__(self):
-        s = "{name}(scale_factor={scale_factor}, mode={mode}, align_corners={align_corners})"
+        s = '{name}(scale_factor={scale_factor}, out_size={out_size}, mode={mode}, align_corners={align_corners}, up={up})' # noqa
         return s.format(
             name=self.__class__.__name__,
             scale_factor=self.scale_factor,
+            out_size=self.out_size,
             mode=self.mode,
-            align_corners=self.align_corners)
+            align_corners=self.align_corners,
+            up=self.up)
 
     def calc_flops(self, x):
         assert (x.shape[0] == 1)
@@ -1142,6 +1337,8 @@ class SEBlock(nn.Module):
         Number of channels.
     reduction : int, default 16
         Squeeze reduction value.
+    mid_channels : int or None, default None
+        Number of middle channels.
     round_mid : bool, default False
         Whether to round middle channel number (make divisible by 8).
     use_conv : bool, default True
@@ -1154,13 +1351,15 @@ class SEBlock(nn.Module):
     def __init__(self,
                  channels,
                  reduction=16,
+                 mid_channels=None,
                  round_mid=False,
                  use_conv=True,
                  mid_activation=(lambda: nn.ReLU(inplace=True)),
                  out_activation=(lambda: nn.Sigmoid())):
         super(SEBlock, self).__init__()
         self.use_conv = use_conv
-        mid_channels = channels // reduction if not round_mid else round_channels(float(channels) / reduction)
+        if mid_channels is None:
+            mid_channels = channels // reduction if not round_mid else round_channels(float(channels) / reduction)
 
         self.pool = nn.AdaptiveAvgPool2d(output_size=1)
         if use_conv:
@@ -1198,6 +1397,196 @@ class SEBlock(nn.Module):
         return x
 
 
+class SABlock(nn.Module):
+    """
+    Split-Attention block from 'ResNeSt: Split-Attention Networks,' https://arxiv.org/abs/2004.08955.
+
+    Parameters:
+    ----------
+    out_channels : int
+        Number of output channels.
+    groups : int
+        Number of channel groups (cardinality, without radix).
+    radix : int
+        Number of splits within a cardinal group.
+    reduction : int, default 4
+        Squeeze reduction value.
+    min_channels : int, default 32
+        Minimal number of squeezed channels.
+    use_conv : bool, default True
+        Whether to convolutional layers instead of fully-connected ones.
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    """
+    def __init__(self,
+                 out_channels,
+                 groups,
+                 radix,
+                 reduction=4,
+                 min_channels=32,
+                 use_conv=True,
+                 bn_eps=1e-5):
+        super(SABlock, self).__init__()
+        self.groups = groups
+        self.radix = radix
+        self.use_conv = use_conv
+        in_channels = out_channels * radix
+        mid_channels = max(in_channels // reduction, min_channels)
+
+        self.pool = nn.AdaptiveAvgPool2d(output_size=1)
+        if use_conv:
+            self.conv1 = conv1x1(
+                in_channels=out_channels,
+                out_channels=mid_channels,
+                bias=True)
+        else:
+            self.fc1 = nn.Linear(
+                in_features=out_channels,
+                out_features=mid_channels)
+        self.bn = nn.BatchNorm2d(
+            num_features=mid_channels,
+            eps=bn_eps)
+        self.activ = nn.ReLU(inplace=True)
+        if use_conv:
+            self.conv2 = conv1x1(
+                in_channels=mid_channels,
+                out_channels=in_channels,
+                bias=True)
+        else:
+            self.fc2 = nn.Linear(
+                in_features=mid_channels,
+                out_features=in_channels)
+        self.softmax = nn.Softmax(dim=1)
+
+    def forward(self, x):
+        batch, channels, height, width = x.size()
+        x = x.view(batch, self.radix, channels // self.radix, height, width)
+        w = x.sum(dim=1)
+        w = self.pool(w)
+        if not self.use_conv:
+            w = w.view(x.size(0), -1)
+        w = self.conv1(w) if self.use_conv else self.fc1(w)
+        w = self.bn(w)
+        w = self.activ(w)
+        w = self.conv2(w) if self.use_conv else self.fc2(w)
+        w = w.view(batch, self.groups, self.radix, -1)
+        w = torch.transpose(w, 1, 2).contiguous()
+        w = self.softmax(w)
+        w = w.view(batch, self.radix, -1, 1, 1)
+        x = x * w
+        x = x.sum(dim=1)
+        return x
+
+
+class SAConvBlock(nn.Module):
+    """
+    Split-Attention convolution block from 'ResNeSt: Split-Attention Networks,' https://arxiv.org/abs/2004.08955.
+
+    Parameters:
+    ----------
+    in_channels : int
+        Number of input channels.
+    out_channels : int
+        Number of output channels.
+    kernel_size : int or tuple/list of 2 int
+        Convolution window size.
+    stride : int or tuple/list of 2 int
+        Strides of the convolution.
+    padding : int, or tuple/list of 2 int, or tuple/list of 4 int
+        Padding value for convolution layer.
+    dilation : int or tuple/list of 2 int, default 1
+        Dilation value for convolution layer.
+    groups : int, default 1
+        Number of groups.
+    bias : bool, default False
+        Whether the layer uses a bias vector.
+    use_bn : bool, default True
+        Whether to use BatchNorm layer.
+    bn_eps : float, default 1e-5
+        Small float added to variance in Batch norm.
+    activation : function or str or None, default nn.ReLU(inplace=True)
+        Activation function or name of activation function.
+    radix : int, default 2
+        Number of splits within a cardinal group.
+    reduction : int, default 4
+        Squeeze reduction value.
+    min_channels : int, default 32
+        Minimal number of squeezed channels.
+    use_conv : bool, default True
+        Whether to convolutional layers instead of fully-connected ones.
+    """
+    def __init__(self,
+                 in_channels,
+                 out_channels,
+                 kernel_size,
+                 stride,
+                 padding,
+                 dilation=1,
+                 groups=1,
+                 bias=False,
+                 use_bn=True,
+                 bn_eps=1e-5,
+                 activation=(lambda: nn.ReLU(inplace=True)),
+                 radix=2,
+                 reduction=4,
+                 min_channels=32,
+                 use_conv=True):
+        super(SAConvBlock, self).__init__()
+        self.conv = ConvBlock(
+            in_channels=in_channels,
+            out_channels=(out_channels * radix),
+            kernel_size=kernel_size,
+            stride=stride,
+            padding=padding,
+            dilation=dilation,
+            groups=(groups * radix),
+            bias=bias,
+            use_bn=use_bn,
+            bn_eps=bn_eps,
+            activation=activation)
+        self.att = SABlock(
+            out_channels=out_channels,
+            groups=groups,
+            radix=radix,
+            reduction=reduction,
+            min_channels=min_channels,
+            use_conv=use_conv,
+            bn_eps=bn_eps)
+
+    def forward(self, x):
+        x = self.conv(x)
+        x = self.att(x)
+        return x
+
+
+def saconv3x3_block(in_channels,
+                    out_channels,
+                    stride=1,
+                    padding=1,
+                    **kwargs):
+    """
+    3x3 version of the Split-Attention convolution block.
+
+    Parameters:
+    ----------
+    in_channels : int
+        Number of input channels.
+    out_channels : int
+        Number of output channels.
+    stride : int or tuple/list of 2 int, default 1
+        Strides of the convolution.
+    padding : int or tuple/list of 2 int, default 1
+        Padding value for convolution layer.
+    """
+    return SAConvBlock(
+        in_channels=in_channels,
+        out_channels=out_channels,
+        kernel_size=3,
+        stride=stride,
+        padding=padding,
+        **kwargs)
+
+
 class DucBlock(nn.Module):
     """
     Dense Upsampling Convolution (DUC) block from 'Understanding Convolution for Semantic Segmentation,'
@@ -1497,7 +1886,7 @@ class SesquialteralHourglass(nn.Module):
         The second skip connection modules as sequential.
     down2_seq : nn.Sequential
         The second down modules as sequential.
-    merge_type : str, default 'con'
+    merge_type : str, default 'cat'
         Type of concatenation of up and skip outputs.
     """
     def __init__(self,
