@@ -1,5 +1,5 @@
 """
-    NASNet-A, implemented in PyTorch.
+    NASNet-A for ImageNet-1K, implemented in PyTorch.
     Original paper: 'Learning Transferable Architectures for Scalable Image Recognition,'
     https://arxiv.org/abs/1707.07012.
 """
@@ -1129,8 +1129,8 @@ class NASNet(nn.Module):
             stride=1))
 
         self.output = nn.Sequential()
-        self.output.add_module('dropout', nn.Dropout(p=0.5))
-        self.output.add_module('fc', nn.Linear(
+        self.output.add_module("dropout", nn.Dropout(p=0.5))
+        self.output.add_module("fc", nn.Linear(
             in_features=in_channels,
             out_features=num_classes))
 
@@ -1159,7 +1159,7 @@ def get_nasnet(repeat,
                in_size,
                model_name=None,
                pretrained=False,
-               root=os.path.join('~', '.torch', 'models'),
+               root=os.path.join("~", ".torch", "models"),
                **kwargs):
     """
     Create NASNet-A model with specific parameters.
@@ -1278,7 +1278,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -1298,7 +1297,7 @@ def _test():
         assert (model != nasnet_4a1056 or weight_count == 5289978)
         assert (model != nasnet_6a4032 or weight_count == 88753150)
 
-        x = Variable(torch.randn(1, 3, net.in_size[0], net.in_size[1]))
+        x = torch.randn(1, 3, net.in_size[0], net.in_size[1])
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
