@@ -1,5 +1,5 @@
 """
-    PNASNet, implemented in PyTorch.
+    PNASNet for ImageNet-1K, implemented in PyTorch.
     Original paper: 'Progressive Neural Architecture Search,' https://arxiv.org/abs/1712.00559.
 """
 
@@ -491,8 +491,8 @@ class PNASNet(nn.Module):
             stride=1))
 
         self.output = nn.Sequential()
-        self.output.add_module('dropout', nn.Dropout(p=0.5))
-        self.output.add_module('fc', nn.Linear(
+        self.output.add_module("dropout", nn.Dropout(p=0.5))
+        self.output.add_module("fc", nn.Linear(
             in_features=in_channels,
             out_features=num_classes))
 
@@ -514,7 +514,7 @@ class PNASNet(nn.Module):
 
 def get_pnasnet(model_name=None,
                 pretrained=False,
-                root=os.path.join('~', '.torch', 'models'),
+                root=os.path.join("~", ".torch", "models"),
                 **kwargs):
     """
     Create PNASNet model with specific parameters.
@@ -579,7 +579,6 @@ def _calc_width(net):
 
 def _test():
     import torch
-    from torch.autograd import Variable
 
     pretrained = False
 
@@ -597,7 +596,7 @@ def _test():
         print("m={}, {}".format(model.__name__, weight_count))
         assert (model != pnasnet5large or weight_count == 86057668)
 
-        x = Variable(torch.randn(1, 3, 331, 331))
+        x = torch.randn(1, 3, 331, 331)
         y = net(x)
         y.sum().backward()
         assert (tuple(y.size()) == (1, 1000))
